@@ -49,13 +49,11 @@ breezy.ui.text.TextUIFactory
 
 import warnings
 
-
-_valid_boolean_strings = dict(yes=True, no=False,
-                              y=True, n=False,
-                              on=True, off=False,
-                              true=True, false=False)
-_valid_boolean_strings['1'] = True
-_valid_boolean_strings['0'] = False
+_valid_boolean_strings = dict(
+    yes=True, no=False, y=True, n=False, on=True, off=False, true=True, false=False
+)
+_valid_boolean_strings["1"] = True
+_valid_boolean_strings["0"] = False
 
 
 def bool_from_string(s, accepted_values=None):
@@ -88,7 +86,7 @@ def bool_from_string(s, accepted_values=None):
     return val
 
 
-class ConfirmationUserInterfacePolicy(object):
+class ConfirmationUserInterfacePolicy:
     """Wrapper for a UIFactory that allows or denies all confirmed actions."""
 
     def __init__(self, wrapped_ui, default_answer, specific_answers):
@@ -109,11 +107,12 @@ class ConfirmationUserInterfacePolicy(object):
         return getattr(self.wrapped_ui, name)
 
     def __repr__(self):
-        return '%s(%r, %r, %r)' % (
+        return "{}({!r}, {!r}, {!r})".format(
             self.__class__.__name__,
             self.wrapped_ui,
             self.default_answer,
-            self.specific_answers)
+            self.specific_answers,
+        )
 
     def confirm_action(self, prompt, confirmation_id, prompt_kwargs):
         if confirmation_id in self.specific_answers:
@@ -122,10 +121,11 @@ class ConfirmationUserInterfacePolicy(object):
             return self.default_answer
         else:
             return self.wrapped_ui.confirm_action(
-                prompt, confirmation_id, prompt_kwargs)
+                prompt, confirmation_id, prompt_kwargs
+            )
 
 
-class UIFactory(object):
+class UIFactory:
     """UI abstraction.
 
     This tells the library how to display things to the user.  Through this
@@ -140,33 +140,38 @@ class UIFactory(object):
     """
 
     _user_warning_templates = dict(
-        cross_format_fetch=("Doing on-the-fly conversion from "
-                            "%(from_format)s to %(to_format)s.\n"
-                            "This may take some time. Upgrade the repositories to the "
-                            "same format for better performance."
-                            ),
-        experimental_format_fetch=("Fetching into experimental format "
-                                   "%(to_format)s.\n"
-                                   "This format may be unreliable or change in the future "
-                                   "without an upgrade path.\n"),
+        cross_format_fetch=(
+            "Doing on-the-fly conversion from "
+            "%(from_format)s to %(to_format)s.\n"
+            "This may take some time. Upgrade the repositories to the "
+            "same format for better performance."
+        ),
+        experimental_format_fetch=(
+            "Fetching into experimental format "
+            "%(to_format)s.\n"
+            "This format may be unreliable or change in the future "
+            "without an upgrade path.\n"
+        ),
         deprecated_command=(
             "The command 'brz %(deprecated_name)s' "
             "has been deprecated in brz %(deprecated_in_version)s. "
-            "Please use 'brz %(recommended_name)s' instead."),
+            "Please use 'brz %(recommended_name)s' instead."
+        ),
         deprecated_command_option=(
             "The option '%(deprecated_name)s' to 'brz %(command)s' "
             "has been deprecated in brz %(deprecated_in_version)s. "
-            "Please use '%(recommended_name)s' instead."),
-        recommend_upgrade=("%(current_format_name)s is deprecated "
-                           "and a better format is available.\n"
-                           "It is recommended that you upgrade by "
-                           "running the command\n"
-                           "  brz upgrade %(basedir)s"),
-        locks_steal_dead=(
-            u"Stole dead lock %(lock_url)s %(other_holder_info)s."),
-        not_checking_ssl_cert=(
-            u"Not checking SSL certificate for %(host)s."),
-        )
+            "Please use '%(recommended_name)s' instead."
+        ),
+        recommend_upgrade=(
+            "%(current_format_name)s is deprecated "
+            "and a better format is available.\n"
+            "It is recommended that you upgrade by "
+            "running the command\n"
+            "  brz upgrade %(basedir)s"
+        ),
+        locks_steal_dead=("Stole dead lock %(lock_url)s %(other_holder_info)s."),
+        not_checking_ssl_cert=("Not checking SSL certificate for %(host)s."),
+    )
 
     def __init__(self):
         self._task_stack = []
@@ -217,7 +222,7 @@ class UIFactory(object):
         """
         return self.get_boolean(prompt % prompt_kwargs)
 
-    def get_password(self, prompt=u'', **kwargs):
+    def get_password(self, prompt="", **kwargs):
         """Prompt the user for a password.
 
         Args:
@@ -236,7 +241,7 @@ class UIFactory(object):
     def is_quiet(self):
         return self._quiet
 
-    def make_output_stream(self, encoding=None, encoding_type='replace'):
+    def make_output_stream(self, encoding=None, encoding_type="replace"):
         """Get a stream for sending out bulk text data.
 
         This is used for commands that produce bulk text, such as log or diff
@@ -260,8 +265,9 @@ class UIFactory(object):
         return out_stream
 
     def _make_output_stream_explicit(self, encoding, encoding_type):
-        raise NotImplementedError("%s doesn't support make_output_stream"
-                                  % (self.__class__.__name__))
+        raise NotImplementedError(
+            "%s doesn't support make_output_stream" % (self.__class__.__name__)
+        )
 
     def nested_progress_bar(self):
         """Return a nested progress bar.
@@ -270,6 +276,7 @@ class UIFactory(object):
         bar.finished().
         """
         from ..progress import ProgressTask
+
         if self._task_stack:
             t = ProgressTask(self._task_stack[-1], self)
         else:
@@ -280,13 +287,11 @@ class UIFactory(object):
     def _progress_finished(self, task):
         """Called by the ProgressTask when it finishes"""
         if not self._task_stack:
-            warnings.warn("%r finished but nothing is active"
-                          % (task,))
+            warnings.warn("%r finished but nothing is active" % (task,))
         if task in self._task_stack:
             self._task_stack.remove(task)
         else:
-            warnings.warn("%r is not in active stack %r"
-                          % (task, self._task_stack))
+            warnings.warn("%r is not in active stack %r" % (task, self._task_stack))
         if not self._task_stack:
             self._progress_all_finished()
 
@@ -313,16 +318,16 @@ class UIFactory(object):
         try:
             template = self._user_warning_templates[warning_id]
         except KeyError:
-            fail = "brz warning: %r, %r" % (warning_id, message_args)
-            warnings.warn("no template for warning: "
-                          + fail)   # so tests will fail etc
+            fail = "brz warning: {!r}, {!r}".format(warning_id, message_args)
+            warnings.warn("no template for warning: " + fail)  # so tests will fail etc
             return str(fail)
         try:
             return str(template) % message_args
         except ValueError as e:
-            fail = "brz unprintable warning: %r, %r, %s" % (
-                warning_id, message_args, e)
-            warnings.warn(fail)   # so tests will fail etc
+            fail = "brz unprintable warning: {!r}, {!r}, {}".format(
+                warning_id, message_args, e
+            )
+            warnings.warn(fail)  # so tests will fail etc
             return str(fail)
 
     def choose(self, msg, choices, default=None):
@@ -357,7 +362,7 @@ class UIFactory(object):
         Returns:
           True or False for y/yes or n/no.
         """
-        choice = self.choose(prompt + '?', '&yes\n&no', default=None)
+        choice = self.choose(prompt + "?", "&yes\n&no", default=None)
         return 0 == choice
 
     def get_integer(self, prompt):
@@ -387,8 +392,11 @@ class UIFactory(object):
           current_format_name: Description of the current format
           basedir: Location of the control dir
         """
-        self.show_user_warning('recommend_upgrade',
-                               current_format_name=current_format_name, basedir=basedir)
+        self.show_user_warning(
+            "recommend_upgrade",
+            current_format_name=current_format_name,
+            basedir=basedir,
+        )
 
     def report_transport_activity(self, transport, byte_count, direction):
         """Called by transports as they do IO.
@@ -457,7 +465,7 @@ class NoninteractiveUIFactory(UIFactory):
         return True
 
     def __repr__(self):
-        return '%s()' % (self.__class__.__name__, )
+        return "{}()".format(self.__class__.__name__)
 
 
 class SilentUIFactory(NoninteractiveUIFactory):
@@ -499,7 +507,7 @@ class CannedInputUIFactory(SilentUIFactory):
         self.responses = responses
 
     def __repr__(self):
-        return "%s(%r)" % (self.__class__.__name__, self.responses)
+        return "{}({!r})".format(self.__class__.__name__, self.responses)
 
     def confirm_action(self, prompt, confirmation_id, args):
         return self.get_boolean(prompt % args)
@@ -510,7 +518,7 @@ class CannedInputUIFactory(SilentUIFactory):
     def get_integer(self, prompt):
         return self.responses.pop(0)
 
-    def get_password(self, prompt=u'', **kwargs):
+    def get_password(self, prompt="", **kwargs):
         return self.responses.pop(0)
 
     def get_username(self, prompt, **kwargs):
@@ -518,8 +526,7 @@ class CannedInputUIFactory(SilentUIFactory):
 
     def assert_all_input_consumed(self):
         if self.responses:
-            raise AssertionError("expected all input in %r to be consumed"
-                                 % (self,))
+            raise AssertionError("expected all input in %r to be consumed" % (self,))
 
 
 ui_factory = SilentUIFactory()
@@ -528,15 +535,15 @@ ui_factory = SilentUIFactory()
 
 
 def make_ui_for_terminal(stdin, stdout, stderr):
-    """Construct and return a suitable UIFactory for a text mode program.
-    """
+    """Construct and return a suitable UIFactory for a text mode program."""
     # this is now always TextUIFactory, which in turn decides whether it
     # should display progress bars etc
     from .text import TextUIFactory
+
     return TextUIFactory(stdin, stdout, stderr)
 
 
-class NullProgressView(object):
+class NullProgressView:
     """Soak up and ignore progress information."""
 
     def clear(self):
@@ -552,7 +559,7 @@ class NullProgressView(object):
         pass
 
 
-class NullOutputStream(object):
+class NullOutputStream:
     """Acts like a file, but discard all output."""
 
     def __init__(self, encoding):
